pub struct ExtensionsMap { /* private fields */ }Expand description
Thread-safe, cloneable storage for arbitrary data keyed by strings Uses type erasure (Any) to support any Send + Sync type
Implementations
Sourceimpl ExtensionsMap
impl ExtensionsMap
Sourcepub fn get<T: Any + Send + Sync + 'static>(&self, key: &str) -> Option<Arc<T>>
pub fn get<T: Any + Send + Sync + 'static>(&self, key: &str) -> Option<Arc<T>>
Retrieve a value from the extensions map
Arguments
key- The key to retrieve
Returns
Some(Arc<T>)if the key exists and the type matchesNoneif the key doesn’t exist or type mismatch occurs
Example
ⓘ
if let Some(user_id) = ctx.extensions.get::<u64>("user_id") {
println!("User ID: {}", user_id);
}Sourcepub fn contains_key(&self, key: &str) -> bool
pub fn contains_key(&self, key: &str) -> bool
Check if a key exists in the extensions map