Module pipe

Module pipe 

Structs

HttpWardMiddlewarePipe
Public wrapper around shared pipeline storage. The internal Vec is wrapped in an Arc so cloning the pipe is cheap (one atomic increment).
HttpWardMiddlewarePipeBuilder
Builder used during configuration time to accumulate Box. Use this builder to add layers; then call build() to obtain the cheap-cloneable pipe.
MiddlewareFatPtr
C-compatible representation of a fat pointer to dyn HttpWardMiddleware.