macro_rules! get_config_from_current_module {
($config_type:ty, $ctx:expr, $req:expr) => { ... };
}Expand description
Macro to get config using current module name automatically Usage: get_config_from_current_module!(MyConfig, ctx, req)
macro_rules! get_config_from_current_module {
($config_type:ty, $ctx:expr, $req:expr) => { ... };
}Macro to get config using current module name automatically Usage: get_config_from_current_module!(MyConfig, ctx, req)