Module middleware_config_ext

Module middleware_config_ext 

Traits

MiddlewareConfigExt
Convenient trait for getting middleware configuration from context

Functions

get_config_from_ctx
Universal function to get middleware configuration from context Usage: get_config_from_ctx::(ctx, req, “my_middleware_name”)
get_config_from_ctx_for_module
Universal function to get middleware configuration from context with module name Usage: get_config_from_ctx_for_module::(ctx, req, “my_module_name”)
get_middleware_config_from_ctx
Convenient function for getting middleware configuration from context
get_middleware_config_typed_from_ctx
Convenient function for getting typed configuration