macro_rules! export_module_with_custom_middleware {
() => { ... };
(env: $env_var:literal) => { ... };
($module_name:expr) => { ... };
}Expand description
Alternative macro for modules that need custom middleware creation logic This provides the logger setup but allows custom create/destroy functions
Usage Options
1. Automatic module name (recommended)
use httpward_core::export_module_with_custom_middleware;
export_module_with_custom_middleware!(); // Uses Cargo.toml name2. Custom module name
use httpward_core::export_module_with_custom_middleware;
export_module_with_custom_middleware!("custom_name");3. Environment variable name (example with literal)
use httpward_core::export_module_with_custom_middleware;
export_module_with_custom_middleware!("my_module_name");